Package: WikipediR
Type: Package
Title: A MediaWiki API Wrapper
Version: 1.7.1
Date: 2024-04-05
Author: Os Keyes [aut, cre], Brock Tilbert [ctb], Clemens Schmid [aut]
Maintainer: Os Keyes <ironholds@gmail.com>
Description: A wrapper for the MediaWiki API, aimed particularly at the
    Wikimedia 'production' wikis, such as Wikipedia. It can be used to retrieve
    page text, information about users or the history of pages, and elements of
    the category tree.
License: MIT + file LICENSE
Imports: httr, jsonlite, magrittr
Suggests: testthat, knitr, WikidataR, pageviews
BugReports: https://github.com/Ironholds/WikipediR/issues
URL: https://github.com/Ironholds/WikipediR/
VignetteBuilder: knitr
RoxygenNote: 7.3.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2024-04-05 17:43:38 UTC; ironholds
Repository: CRAN
Date/Publication: 2024-04-05 18:13:00 UTC
Built: R 4.6.0; ; 2026-04-26 08:43:30 UTC; unix
