# Generated by roxygen2: do not edit by hand

S3method(parse_response,actiontoken)
S3method(parse_response,blink)
S3method(parse_response,catpages)
S3method(parse_response,createpage)
S3method(parse_response,elink)
S3method(parse_response,login)
S3method(parse_response,pagecats)
S3method(parse_response,pageinfo)
S3method(parse_response,pcontent)
S3method(parse_response,plink)
S3method(parse_response,prelogintoken)
S3method(parse_response,rchanges)
S3method(parse_response,rcontent)
S3method(parse_response,rdiff)
S3method(parse_response,ucontribs)
S3method(parse_response,uinfo)
export(categories_in_page)
export(create_pages)
export(login)
export(page_backlinks)
export(page_content)
export(page_external_links)
export(page_info)
export(page_links)
export(pages_in_category)
export(parse_response)
export(query)
export(random_page)
export(recent_changes)
export(revision_content)
export(revision_diff)
export(user_contributions)
export(user_information)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,stop_for_status)
importFrom(httr,user_agent)
importFrom(jsonlite,fromJSON)
importFrom(magrittr,"%>%")
importFrom(utils,URLencode)
