#' @title A client library for MediaWiki's API
#' @name WikipediR
#' @description This package provides functions for accessing the MediaWiki API, either for
#' Wikimedia projects or any other MediaWiki instance. For more information, see the
#' \href{https://CRAN.R-project.org/package=WikipediR/vignettes/WikipediR.html}{vignette}.
#' 
#' @seealso The \href{https://CRAN.R-project.org/package=WikipediR/vignettes/WikipediR.html}{package vignette}.
#' @docType package
#' @importFrom httr GET user_agent stop_for_status
#' @importFrom utils URLencode
#' @aliases WikipediR WikipediR-package
NULL